package com.example.GoodByeWorld;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;

public class GoodByeWorld extends Activity {
	/* 
	 * Create an unique request code. This is to identify the result from diff
	 * requests (onActivityResult).
	 * */
	private static final int REQUEST_PICK_IMAGE = 1;
	
    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        /*
         * Ask GoodByeWorld Activity to manage layout defined in main.xml.
         * Any Views (buttons, textboxes, ..., etc) will be instantiated.
         */
        setContentView(R.layout.main);
    
        /* Make a reference to the button defined in layout (main.xml).
         */
        Button button = (Button)findViewById(R.id.helloButton);
        
        /* 
         * Attach an event handler to the button's click event.
         * When button is clicked, create an Intent. Indicate in the intent that
         * I wish to make a selection (Intent.ACTION_PICK), and I wish to select
         * items of image type (image/*).
         * Hint: You can try "image/jpeg".
         */
        button.setOnClickListener(new OnClickListener() {
        	@Override
        	public void onClick(View arg0) {
        		Intent pickImage = new Intent(Intent.ACTION_PICK);
        		pickImage.setType("image/*");
        		/*
        		 * Send the Intent to Android system. Tell Android to launch
        		 * an Activity handle my request. I have also assigned a request 
        		 * code (REQUEST_PICK_IMAGE) for this request.
        		 */
            	startActivityForResult(pickImage, REQUEST_PICK_IMAGE);
        	}
        });
    }
    
    /*
     * This method is invoked when request is completed, and the Activity 
     * returns a result. As result from requests may invoke this method,
     * the requestCode helps us to identify them.
     */
    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
    	super.onActivityResult(requestCode, resultCode, data);
    	
    	/*
    	 * resultCode tells us the status of the request. RESULT_OK is already
    	 * defined in parent class. 
    	 * I verify that the requestCode is correct.
    	 */
    	if ((resultCode == RESULT_OK) && (requestCode == REQUEST_PICK_IMAGE)) {
    		/*
    		 * After image is selected (from Image Gallery app) the result is
    		 * encapsulated in an Intent. I modified the Intent and reuse it to 
    		 * send a request. I specified that it must be handled by 
    		 * PhotoViewer. startActivity() method send the Intend to Android
    		 * system, which in turn send it to PhotoViewer. Request code is not
    		 * needed as I do not expect any result from the PhotoViewer.
    		 */
    		data.setClass(this, PhotoViewer.class);
    		startActivity(data);
    	}
    	else {
    		/*
    		 * This message can be monitored in LogCat, provided by ADT plugin.
    		 */
    		Log.e("GoodByeWorld", "Cannot pick image.");
    	}
    }
}