package com.example.GoodByeWorld;

import android.app.Activity;
import android.graphics.ColorMatrixColorFilter;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.widget.ImageView;

public class PhotoViewer extends Activity {
	/*
	 * The View object that is responsible for displying the image.
	 */
	private ImageView photoView;
	/*
	 * Assign an unique for each menu item.
	 */
	private static final int MENU_RED = Menu.FIRST;
	private static final int MENU_GREEN = Menu.FIRST + 1;
	private static final int MENU_BLUE = Menu.FIRST + 2;
	private static final int MENU_RAND = Menu.FIRST + 3;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		/*
		 * Ask PhotoViewer Activity to manage the layout defined in 
		 * photo_viewer.xml. ImageView will automatically be instantiated.
		 */
		setContentView(R.layout.photo_viewer);
		
		/*
		 * Set reference to the ImageView defined in photo_viewer.xml.
		 */
		photoView = (ImageView)findViewById(R.id.photoView);
		/*
		 * I expect this Activity to be launch by another Component 
		 * (e.g. GoodByeWorld Activity), and URI address for the image file
		 * is defined in the Intent.
		 * Tell photoView where the image file is located. photoView will 
		 * load the image file.
		 */
		photoView.setImageURI(getIntent().getData());
	}
	
	/*
	 * http://bit.ly/E5i1R
	 * Template pattern used here. This method is invoked once, on the first
	 * time the options menu is display. I override this method to create
	 * menu entries.
	 */
	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		super.onCreateOptionsMenu(menu);
		
		/*
		 * http://bit.ly/4EIcpT
		 */
		menu.add(Menu.NONE, MENU_RED, Menu.NONE, "Filter Red");
		menu.add(Menu.NONE, MENU_GREEN, Menu.NONE, "Filter Green");
		menu.add(Menu.NONE, MENU_BLUE, Menu.NONE, "Filter Blue");
		menu.add(Menu.NONE, MENU_RAND, Menu.NONE, "Random Filter");
		
		return true;
	}
	
	/*
	 * Invoked when menu item is selected. Assign a new color filter to the 
	 * photoView. A ColorFilter (http://bit.ly/sy9f1) alters the color values.
	 */
	@Override
	public boolean onMenuItemSelected(int featureId, MenuItem item) {
		super.onMenuItemSelected(featureId, item);
		
		switch(item.getItemId()) {
		case MENU_RED:
			photoView.setColorFilter(redFilter());
			break;
		case MENU_GREEN:
			photoView.setColorFilter(greenFilter());
			break;
		case MENU_BLUE:
			photoView.setColorFilter(blueFilter());
			break;
		case MENU_RAND:
			photoView.setColorFilter(randFilter());
			break;
		}
		
		return true;
	}
	
	/*
	 * ColorMatrixColorFilter IsA ColorFilter. It is basically a 4 by 5 matrix.
	 * http://bit.ly/2xt1YC
	 */
	private ColorMatrixColorFilter redFilter() {
		return new ColorMatrixColorFilter(new float[] {
			0,	0,	0,	0,	0,
			0,	1,	0,	0,	0,
			0,	0,	1,	0,	0,
			0,	0,	0,	1,	0
		});
	}
	
	private ColorMatrixColorFilter greenFilter() {
		return new ColorMatrixColorFilter(new float[] {
			1,	0,	0,	0,	0,
			0,	0,	0,	0,	0,
			0,	0,	1,	0,	0,
			0,	0,	0,	1,	0
		});
	}
	
	private ColorMatrixColorFilter blueFilter() {
		return new ColorMatrixColorFilter(new float[] {
			1,	0,	0,	0,	0,
			0,	1,	0,	0,	0,
			0,	0,	0,	0,	0,
			0,	0,	0,	1,	0
		});
	}
	
	private ColorMatrixColorFilter randFilter() {
		float red = (float)Math.random();
		float green = (float)Math.random();
		float blue = (float)Math.random();
		Log.d("tmp", String.valueOf(red) + "," + String.valueOf(green) + "," + String.valueOf(blue));
		return new ColorMatrixColorFilter(new float[] {
			red,	0,	0,	0,	0,
			0,	green,	0,	0,	0,
			0,	0,	blue,	0,	0,
			0,	0,	0,	1,	0
		});
	}
}
